@@ -10,7 +10,7 @@
 
 #include "api.h"
 
-#define VERSION 	"0.9.3"
+#define VERSION 	"0.9.7"
 
 #define MODE_NORMAL	0x0
 #define MODE_CHECK	0x1
@@ -110,6 +110,8 @@ static void teardown(void)
  */
 int main(int argc, char **argv)
 {
+  int status = 0;
+
   setvbuf(stdin,  NULL, _IONBF, 0);
   setvbuf(stdout, NULL, _IONBF, 0);
   setvbuf(stderr, NULL, _IONBF, 0);
@@ -127,10 +129,10 @@ int main(int argc, char **argv)
 
   /* execute operation */
   if (mode == MODE_NORMAL) {  
-    arena_execute_script(context, script);
+    status = arena_execute_script(context, script);
   } else if (mode == MODE_DUMP) {
     arena_dump_script(script);
   }
 
-  return 0;
+  return (status >= 0) ? status : 1;
 }
