@@ -24,6 +24,7 @@ value *eval_lambda(arena_state *s, expr *ex)
   entry = symtab_stack_lookup(s, "\\lambda");
   if (!entry || entry->type != SYMTAB_ENTRY_FUNCTION) {
     fatal(s, "lambda expression did not yield function");
+    return value_make_void();
   }
   res = value_make_fn(entry->entry_u.sig);
   symtab_stack_leave(s);
@@ -43,6 +44,10 @@ value *eval_expr(arena_state *s, expr *ex)
   
   sanity(ex);
 
+  if (s->except_flag || s->exit_flag) {
+    return value_make_void();
+  }
+
   /*
    * record source position for error printing
    */
