@@ -23,11 +23,12 @@ void eval_stmt_list(arena_state *s, stmt_list *list, int cookie)
   
   sanity(list);
   
-  if (s->return_flag) return;
+  if (s->return_flag || s->exit_flag) return;
   
   for (i = 0; i < list->len; i++) {
     eval_stmt(s, list->list[i], cookie);
-    if (s->continue_flag || s->return_flag || s->except_flag) break;
+    if (s->continue_flag || s->return_flag ||
+        s->except_flag   || s->exit_flag) break;
   }
 }
 
@@ -94,6 +95,7 @@ static value *run_func(arena_state *s, void *data, void *def,
 
   if (++s->func_flag < 1) {
     fatal(s, "too deep function call nesting");
+    return value_make_void();
   }
 
   varargs(s, argc, argv);
@@ -168,7 +170,7 @@ void eval_stmt(arena_state *s, stmt *st, int cookie)
   
   sanity(st);
 
-  if (s->return_flag || s->except_flag) return;
+  if (s->return_flag || s->except_flag || s->exit_flag) return;
 
   switch (st->type) {
     case STMT_SWITCH:
@@ -201,6 +203,7 @@ void eval_stmt(arena_state *s, stmt *st, int cookie)
       /* while loop */
       if (++s->loop_flag < 1) {
         fatal(s, "too deep loop nesting");
+        return;
       }
       while ((res = runtest(s, st->expr)) == 1) {
         eval_stmt(s, st->true_case, cookie);
@@ -214,6 +217,7 @@ void eval_stmt(arena_state *s, stmt *st, int cookie)
       /* do loop */
       if (++s->loop_flag < 1) {
         fatal(s, "too deep loop nesting");
+        return;
       }
       do {
         eval_stmt(s, st->true_case, cookie);
@@ -229,6 +233,7 @@ void eval_stmt(arena_state *s, stmt *st, int cookie)
       /* for loop */
       if (++s->loop_flag < 1) {
         fatal(s, "too deep loop nesting");
+        return;
       }
       val = eval_expr(s, st->init);
       value_free(val);
@@ -279,6 +284,7 @@ void eval_stmt(arena_state *s, stmt *st, int cookie)
     case STMT_TRY:
       if (++s->try_flag < 1) {
         fatal(s, "too deep try block nesting");
+        return;
       }
       eval_stmt(s, st->true_case, cookie);
       if (s->except_flag) {
@@ -291,10 +297,13 @@ void eval_stmt(arena_state *s, stmt *st, int cookie)
       --s->try_flag;
       break;
     case STMT_THROW:
-      if (!s->try_flag) {
-        fatal(s, "uncaught exception");
-      }
       s->except_value = eval_expr(s, st->expr);
+      if (!s->try_flag) {
+        value_free(s->except_value);
+        s->except_value = NULL;
+        fatal(s, "uncaught exception");
+        return;
+      }
       s->except_flag = 1;
       break;
     case STMT_TMPL:
