@@ -18,8 +18,8 @@ expr *expr_alloc(void)
   expr *ex;
   
   ex = oom(calloc(sizeof(expr), 1));
-  ex->file = source_file;
-  ex->line = source_line;
+  ex->file = parser_state->source_file;
+  ex->line = parser_state->source_line;
   
   return ex;
 }
