@@ -53,24 +53,14 @@ typedef struct {
 } value_array;
 #define ARRAY_GROWTH	100
 
-/*
- * Defined resource types
- */
-typedef enum {
-  RESOURCE_FILE	= 1,
-  RESOURCE_DICT = 2,
-  RESOURCE_MEM  = 3,
-  RESOURCE_LIB  = 4
-} res_type;
-
 /*
  * Resource value structure
  */
 typedef struct {
-  int		type;
   int		refcount;
   void		*data;
   void		(*release)(void *);
+  void		*(*get)(void *);
 } value_res;
 
 /*
@@ -127,7 +117,7 @@ value *value_make_memstring(const void *buf, int len);
 value *value_make_array(void);
 value *value_make_struct(void);
 value *value_make_fn(void *sig);
-value *value_make_resource(int type, void *data, void (*release)(void *));
+value *value_make_resource(void *data, void (*release)(void *));
 
 /*
  * Value copy
