@@ -17,20 +17,20 @@
  */
 static value *copy_array(value *val)
 {
-  value **data = val->value_u.array_val.value;
-  int len      = val->value_u.array_val.len;
-  value *copy;
-  int i;
+  int size  = val->value_u.array_val.size;
+  value **a = val->value_u.array_val.value;
+  value **b, *copy;
   
-  copy = value_alloc(VALUE_TYPE_ARRAY);
+  copy  = value_alloc(VALUE_TYPE_ARRAY);
+  *copy = *val;
 
-  copy->value_u.array_val.len = len;
-  if (len > 0) {
-    copy->value_u.array_val.value = oom(malloc(sizeof(value *) * len));
-  }
-
-  for (i = 0; i < len; i++) {
-    copy->value_u.array_val.value[i] = value_copy(data[i]);
+  if (a) {
+    copy->value_u.array_val.value = oom(malloc((size + 1) * sizeof(value *)));
+    b = copy->value_u.array_val.value;
+    while (*a) {
+      *b++ = value_copy(*a++);
+    }
+    *b = NULL;
   }
   return copy;
 }
