@@ -193,7 +193,7 @@ void value_dump(const value *val, int depth, int skip_flag)
         print_fn(val->value_u.fn_val);
         break;
       case VALUE_TYPE_RES:
-        printf("resource: %i[#%i]", val->value_u.res_val->type,
+        printf("resource: 0x%08x[#%i]", (int) val->value_u.res_val->data,
           val->value_u.res_val->refcount);
         break;
       default:
