@@ -31,7 +31,17 @@ value *dict_open(arena_state *st, unsigned int argc, value **argv)
     return value_make_void();
   }
   
-  return value_make_resource(RESOURCE_DICT, symtab_alloc(order), dict_free);
+  return value_make_resource(symtab_alloc(order), dict_free);
+}
+
+/*
+ * Check whether resource is dictionary resource
+ */
+value *dict_is_resource(arena_state *s, unsigned int argc, value **argv)
+{
+  void *type = argv[0]->value_u.res_val->release;
+  
+  return value_make_bool(type == dict_free);
 }
 
 /*
@@ -42,12 +52,12 @@ value *dict_open(arena_state *st, unsigned int argc, value **argv)
  */
 value *dict_read(arena_state *st, unsigned int argc, value **argv)
 {
-  int type  = argv[0]->value_u.res_val->type;
-  symtab *s = argv[0]->value_u.res_val->data;
-  const char *name = argv[1]->value_u.string_val.value;
+  void *type = argv[0]->value_u.res_val->release;
+  symtab *s  = argv[0]->value_u.res_val->data;
+  const char *name = argv[1]->value_u.string_val.value; 
   symtab_entry *entry;
   
-  if (type != RESOURCE_DICT || !s || !value_str_compat(argv[1])) {
+  if (type != dict_free || !s || !value_str_compat(argv[1])) {
     return value_make_void();
   }
   entry = symtab_lookup(s, name);
@@ -66,12 +76,12 @@ value *dict_read(arena_state *st, unsigned int argc, value **argv)
  */
 value *dict_write(arena_state *st, unsigned int argc, value **argv)
 {
-  int type  = argv[0]->value_u.res_val->type;
-  symtab *s = argv[0]->value_u.res_val->data;
+  void *type = argv[0]->value_u.res_val->release;
+  symtab *s  = argv[0]->value_u.res_val->data;
   const char *name = argv[1]->value_u.string_val.value;
   value *val = argv[2];
   
-  if (type != RESOURCE_DICT || !s || !value_str_compat(argv[1])) {
+  if (type != dict_free || !s || !value_str_compat(argv[1])) {
     return value_make_bool(0);
   }
   
@@ -86,11 +96,11 @@ value *dict_write(arena_state *st, unsigned int argc, value **argv)
  */
 value *dict_remove(arena_state *st, unsigned int argc, value **argv)
 {
-  int type  = argv[0]->value_u.res_val->type;
-  symtab *s = argv[0]->value_u.res_val->data;
+  void *type = argv[0]->value_u.res_val->release;
+  symtab *s  = argv[0]->value_u.res_val->data;
   const char *name = argv[1]->value_u.string_val.value;
   
-  if (type != RESOURCE_DICT || !s || !value_str_compat(argv[1])) {
+  if (type != dict_free || !s || !value_str_compat(argv[1])) {
     return value_make_bool(0);
   }
   
@@ -105,12 +115,12 @@ value *dict_remove(arena_state *st, unsigned int argc, value **argv)
  */
 value *dict_exists(arena_state *st, unsigned int argc, value **argv)
 {
-  int type  = argv[0]->value_u.res_val->type;
-  symtab *s = argv[0]->value_u.res_val->data;
+  void *type = argv[0]->value_u.res_val->release;
+  symtab *s  = argv[0]->value_u.res_val->data;
   const char *name = argv[1]->value_u.string_val.value;
   symtab_entry *entry;
   
-  if (type != RESOURCE_DICT || !s || !value_str_compat(argv[1])) {
+  if (type != dict_free || !s || !value_str_compat(argv[1])) {
     return value_make_bool(0);
   }
   entry = symtab_lookup(s, name);
@@ -125,10 +135,10 @@ value *dict_exists(arena_state *st, unsigned int argc, value **argv)
  */
 value *dict_close(arena_state *st, unsigned int argc, value **argv)
 {
-  int type  = argv[0]->value_u.res_val->type;
-  symtab *s = argv[0]->value_u.res_val->data;
+  void *type = argv[0]->value_u.res_val->release;
+  symtab *s  = argv[0]->value_u.res_val->data;
   
-  if (type == RESOURCE_DICT && s) {
+  if (type == dict_free && s) {
     symtab_free(s);
     argv[0]->value_u.res_val->data = NULL;
   }
