@@ -165,6 +165,7 @@ static stdlib_func std[] = {
   { "trim",		str_trim,		1,	"S",	's'	},
 
   /* file I/O functions */
+  { "is_file_resource",	file_is_resource,	1,	"r",	'b'	},
   { "fopen",		file_open,		2,	"ss",	'?'	},
   { "fseek",		file_seek,		2,	"ri",	'b'	},
   { "ftell",		file_tell,		1,	"r",	'?'	},
@@ -189,6 +190,7 @@ static stdlib_func std[] = {
   { "localeconv",	lc_localeconv,		0,	"",	'?'	},
 
   /* dictionary functions */    
+  { "is_dict_resource",	dict_is_resource,	1,	"r",	'b'	},
   { "dopen",		dict_open,		1,	"i",	'?'	},
   { "dread",		dict_read,		2,	"rS",	'?'	},
   { "dwrite",		dict_write,		3,	"rS?",	'b'	},
@@ -255,6 +257,7 @@ static stdlib_func std[] = {
   { "replicate",	list_replicate,		2,	"?i",	'a'	},
 
   /* foreign function interface */
+  { "is_dyn_resource",	dyn_is_resource,	1,	"r",	'b'	},
   { "dyn_supported",	dyn_supported,		0,	"",	'b'	},
   { "dyn_open",		dyn_open,		1,	"s",	'?'	},
   { "dyn_close",	dyn_close,		1,	"r",	'v'	},	
@@ -265,25 +268,44 @@ static stdlib_func std[] = {
   { "dyn_call_ptr",	dyn_call_ptr,		2,	"rs",	'?'	},
 
   /* memory handling functions */
+  { "is_mem_resource",	mem_is_resource,	1,	"r",	'b'	},
   { "malloc",		mem_malloc,		1,	"i",	'?'	},
   { "calloc",		mem_calloc,		2,	"ii",	'?'	},
+  { "realloc",		mem_realloc,		2,	"ri",	'b'	},
   { "free",		mem_free,		1,	"r",	'v'	},
   { "cnull",		mem_cnull,		0,	"",	'r'	},
   { "cstring",		mem_cstring,		1,	"S",	'?'	},
   { "mputchar",		mem_put_char,		3,	"rii",	'b'	},
   { "mputshort",	mem_put_short,		3,	"rii",	'b'	},
   { "mputint",		mem_put_int,		3,	"rii",	'b'	},
+  { "mputfloat",	mem_put_float,		3,	"rif",	'b'	},
+  { "mputdouble",	mem_put_double,		3,	"rif",	'b'	},
   { "mputptr",		mem_put_pointer,	3,	"rir",	'b'	},
   { "mgetchar",		mem_get_char,		2,	"ri",	'?'	},
   { "mgetshort",	mem_get_short,		2,	"ri",	'?'	},
   { "mgetint",		mem_get_int,		2,	"ri",	'?'	},
+  { "mgetfloat",	mem_get_float,		2,	"ri",	'?'	},
+  { "mgetdouble",	mem_get_double,		2,	"ri",	'?'	},
   { "mgetptr",		mem_get_pointer,	3,	"rib",	'?'	},
   { "mstring",		mem_string,		2,	"ri",	'?'	},
   { "is_rw",		mem_is_rw,		1,	"r",	'b'	},
   { "msize",		mem_size,		1,	"r",	'?'	},
+  { "memcpy",		mem_cpy,		5,	"ririi",'b'	},
+  { "memmove",		mem_move,		5,	"ririi",'b'	},
+  { "memcmp",		mem_cmp,		5,	"ririi",'?'	},
+  { "memchr",		mem_chr,		4,	"riii",	'?'	},
+  { "memset",		mem_set,		4,	"riii",	'b'	},
+
+  /* PCRE regular expression functions */
+  { "is_pcre_resource",	preg_is_resource,	1,	"r",	'b'	},
+  { "pcre_supported",	preg_supported,		0,	"",	'b'	},
+  { "pcre_compile",	preg_compile,		2,	"si",	'?'	},
+  { "pcre_match",	preg_match,		2,	"rsi",	'?'	},
+  { "pcre_exec",	preg_exec,		2,	"rsi",	'?'	},
+  { "pcre_free",	preg_free,		1,	"r",	'v'	},
   
   /* list terminator */
-  { NULL,		NULL,			0,	NULL	}
+  { NULL,		NULL,			0,	NULL,	0	}
 };
 
 /*
@@ -349,5 +371,6 @@ void stdlib_register(arena_state *s, int argc, char **argv)
   }
 
   file_init(s);  
+  preg_init(s);
   register_args(s, argc, argv);
 }
