@@ -5,6 +5,7 @@
  */
 
 #include <ctype.h> 
+#include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
  
@@ -65,6 +66,7 @@ value *str_concat(arena_state *s, unsigned int argc, value **argv)
  */
 value *str_leftmost(arena_state *s, unsigned int argc, value **argv)
 {
+  char *str = argv[0]->value_u.string_val.value;
   char search;
   char *pos;
   
@@ -74,12 +76,11 @@ value *str_leftmost(arena_state *s, unsigned int argc, value **argv)
   }
   search = argv[1]->value_u.string_val.value[0];
   
-  pos = memchr(argv[0]->value_u.string_val.value, search,
-    argv[0]->value_u.string_val.len);
+  pos = memchr(str, search, argv[0]->value_u.string_val.len);
   if (!pos) {
     return value_make_void();
   }
-  return value_make_int((int) pos - (int) argv[0]->value_u.string_val.value);
+  return value_make_int((ptrdiff_t) pos - (ptrdiff_t) str);
 }
 
 /*
@@ -104,7 +105,7 @@ value *str_rightmost(arena_state *s, unsigned int argc, value **argv)
   next = pos + argv[0]->value_u.string_val.len - 1;
   while (next >= pos) {
     if (*next == search) {
-      return value_make_int((int) next - (int) pos);
+      return value_make_int((ptrdiff_t) next - (ptrdiff_t) pos);
     }
     --next;
   }
@@ -138,7 +139,7 @@ value *str_strpos(arena_state *s, unsigned int argc, value **argv)
   end = str1 + len1 - len2;
   while (pos <= end) {
     if (memcmp(pos, str2, len2) == 0) {
-      return value_make_int((int) pos - (int) str1);
+      return value_make_int((ptrdiff_t) pos - (ptrdiff_t) str1);
     }
     ++pos;
   }
