@@ -18,9 +18,9 @@ value *sys_exit(arena_state *s, unsigned int argc, value **argv)
 {
   int status = argv[0]->value_u.int_val;
 
-  exit(status);
-  /* NOT REACHED */
-  return NULL;
+  s->exit_flag  = 1;
+  s->exit_value = status;
+  return value_make_void();
 }
 
 /*
