@@ -5,6 +5,7 @@
  */
 
 #include <stdlib.h>
+#include <string.h>
 #include <time.h>
 
 #include "stdlib.h"
@@ -106,6 +107,8 @@ static struct tm mkstructtm(value *st)
   symtab *sym = st->value_u.struct_val;
   struct tm t;
 
+  memset(&t, 0, sizeof(struct tm));
+
   t.tm_sec   = getint(sym, "tm_sec");
   t.tm_min   = getint(sym, "tm_min");
   t.tm_hour  = getint(sym, "tm_hour");
