@@ -27,7 +27,7 @@ static void runscript(const char *name, const char *dir, int want_success)
   if (want_success) {
     test_assert(res == 0);
   } else {
-    test_assert(res > 0);
+    test_assert(res != 0);
   }
 }
 
@@ -65,6 +65,7 @@ void complex_test(void)
   runscript("lambda", "semantic", 1);
   runscript("reference", "semantic", 1);
   runscript("source", "semantic", 1);
+  runscript("order", "semantic", 1);
 
   test_section("standard library");
   runscript("runtime", "library", 1);
@@ -82,6 +83,8 @@ void complex_test(void)
   runscript("function", "library", 1);
   runscript("list", "library", 1);
   runscript("memory", "library", 1);
+  runscript("foreign", "library", 1);
+  runscript("pcre", "library", 1);
   
   test_section("example programs");
   runscript("bubble", "complex", 1);
